/*
				GNU GENERAL PUBLIC LICENSE
                 Version 3, 29 June 2007

 Copyright (C) 2007 Free Software Foundation, Inc. <https://fsf.org/>
 Everyone is permitted to copy and distribute verbatim copies
 of this license document, but changing it is not allowed.

 http-wokou, An HTTP Proxying framework for bypassing DNS Security
 Copyright (C) 2024 Russell Hrubesky, ChiralWorks Software LLC

 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation, either version 3 of the License, or
 (at your option) any later version.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with this program.  If not, see <https://www.gnu.org/licenses/>.

*/

package httpserver

import (
	"fmt"

	"github.com/patrickmn/go-cache"
)

type CachedResource struct {
	Data  []byte
	Ctype string
	Rcode int
}

func NewCachedResource(data []byte, ctype string, rcode int) *CachedResource {
	return &CachedResource{
		Data:  data,
		Ctype: ctype,
		Rcode: rcode,
	}
}

func (c *Controller) CacheResource(key string, resource *CachedResource) {
	c.cache.Set(key, resource, cache.DefaultExpiration)
}

func (c *Controller) GetResource(key string) *CachedResource {
	resource, found := c.cache.Get(key)
	if found {
		fmt.Printf("Cache Hit! Found resource for URI: %s\n", key)
		return resource.(*CachedResource)
	}
	return nil
}
