/*
				GNU GENERAL PUBLIC LICENSE
                 Version 3, 29 June 2007

 Copyright (C) 2007 Free Software Foundation, Inc. <https://fsf.org/>
 Everyone is permitted to copy and distribute verbatim copies
 of this license document, but changing it is not allowed.

 http-wokou, An HTTP Proxying framework for bypassing DNS Security
 Copyright (C) 2024 Russell Hrubesky, ChiralWorks Software LLC

 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation, either version 3 of the License, or
 (at your option) any later version.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with this program.  If not, see <https://www.gnu.org/licenses/>.

*/

package httpserver

import (
	"encoding/json"
	"log"
	"os"
)

type PageMod struct {
	Target string `json:"target"`
	Search string `json:"search"`
	Sub    string `json:"sub"`
}

type AllPageMods struct {
	Content []*PageMod `json:"modifications"`
}

/*
Load page modifications from the config/pagemod directory

	:param loc: the path to the pagemods directory
*/
func LoadPageMods(loc string) *AllPageMods {
	b, err := os.ReadFile(loc)
	if err != nil {
		log.Fatal("Couldnt load the page modification config from: ", loc, ". Error: ", err)
	}
	var pgMod AllPageMods
	err = json.Unmarshal(b, &pgMod)
	if err != nil {
		log.Fatal("There was an error loading the configuration: ", err)
	}
	return &pgMod

}
